Package: dynwrap
Type: Package
Title: Representing and Inferring Single-Cell Trajectories
Description: Provides functionality to infer trajectories from single-cell data,
  represent them into a common format, and adapt them. Other biological information
  can also be added, such as cellular grouping, RNA velocity and annotation.
  Saelens et al. (2019) <doi:10.1038/s41587-019-0071-9>.
Version: 1.3.0
Authors@R: c(
    person(
      "Robrecht", 
      "Cannoodt", 
      email = "rcannood@gmail.com", 
      role = c("aut", "cre"),
      comment = c(ORCID = "0000-0003-3641-729X")
    ),
    person(
      "Wouter", 
      "Saelens", 
      email = "wouter.saelens@gmail.com", 
      role = c("aut"), 
      comment = c(ORCID = "0000-0002-7114-6248")
    )
  )
URL: https://github.com/dynverse/dynwrap
BugReports: https://github.com/dynverse/dynwrap/issues
License: MIT + file LICENSE
LazyData: TRUE
RoxygenNote: 7.3.3
Encoding: UTF-8
Depends: R (>= 4.1.0)
Imports: assertthat, babelwhale, crayon, dplyr, dynutils (>= 1.0.3),
        dynparam, igraph, glue, Matrix, methods, purrr (>= 1.0.0),
        processx, readr, stringr, reshape2, tibble, tidyr, yaml
Suggests: covr, dyndimred, hdf5r, knitr, pkgload, ranger, rmarkdown,
        testthat
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-03-31 11:39:08 UTC; rcannood
Author: Robrecht Cannoodt [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-3641-729X>),
  Wouter Saelens [aut] (ORCID: <https://orcid.org/0000-0002-7114-6248>)
Maintainer: Robrecht Cannoodt <rcannood@gmail.com>
Repository: CRAN
Date/Publication: 2026-03-31 22:40:25 UTC
Built: R 4.6.0; ; 2026-04-30 10:29:08 UTC; unix
