# Generated by roxygen2: do not edit by hand

export(add_branch_trajectory)
export(add_cell_graph)
export(add_cell_waypoints)
export(add_cluster_graph)
export(add_cyclic_trajectory)
export(add_dimred)
export(add_dimred_projection)
export(add_end_state_probabilities)
export(add_expression)
export(add_feature_importance)
export(add_grouping)
export(add_linear_trajectory)
export(add_prior_information)
export(add_pseudotime)
export(add_regulatory_network)
export(add_root)
export(add_root_using_expression)
export(add_tde_overall)
export(add_timing_checkpoint)
export(add_timings)
export(add_trajectory)
export(add_waypoints)
export(calculate_average_by_group)
export(calculate_geodesic_distances)
export(calculate_pseudotime)
export(calculate_trajectory_dimred)
export(classify_milestone_network)
export(compute_tented_geodesic_distances)
export(convert_definition)
export(convert_milestone_percentages_to_progressions)
export(convert_progressions_to_milestone_percentages)
export(create_config)
export(create_docker_config)
export(create_singularity_config)
export(create_ti_method_container)
export(create_ti_method_definition)
export(create_ti_method_r)
export(def_author)
export(def_container)
export(def_manuscript)
export(def_method)
export(def_package)
export(def_parameters)
export(def_wrapper)
export(definition)
export(determine_cell_trajectory_positions)
export(flip_edges)
export(gather_cells_at_milestones)
export(generate_parameter_documentation)
export(generate_prior_information)
export(get_default_config)
export(get_default_parameters)
export(get_dimred)
export(get_expression)
export(get_grouping)
export(get_milestone_labelling)
export(get_ti_methods)
export(group_onto_nearest_milestones)
export(group_onto_trajectory_edges)
export(infer_trajectories)
export(infer_trajectory)
export(is_data_wrapper)
export(is_rooted)
export(is_ti_method)
export(is_wrapper_with_dimred)
export(is_wrapper_with_expression)
export(is_wrapper_with_feature_importance)
export(is_wrapper_with_grouping)
export(is_wrapper_with_milestone_labelling)
export(is_wrapper_with_prior_information)
export(is_wrapper_with_timings)
export(is_wrapper_with_trajectory)
export(is_wrapper_with_waypoint_cells)
export(is_wrapper_with_waypoints)
export(label_milestones)
export(label_milestones_markers)
export(project_milestones)
export(project_trajectory)
export(project_waypoints)
export(random_seed)
export(remove_root)
export(select_waypoint_cells)
export(select_waypoints)
export(set_default_config)
export(simplify_igraph_network)
export(simplify_trajectory)
export(test_docker_installation)
export(test_h5_installation)
export(test_singularity_installation)
export(wrap_data)
export(wrap_expression)
import(assertthat)
import(dplyr)
import(dynparam)
import(dynutils)
import(purrr)
import(readr)
import(tidyr)
importFrom(Matrix,Matrix)
importFrom(babelwhale,create_config)
importFrom(babelwhale,create_docker_config)
importFrom(babelwhale,create_singularity_config)
importFrom(babelwhale,get_default_config)
importFrom(babelwhale,list_docker_images)
importFrom(babelwhale,pull_container)
importFrom(babelwhale,set_default_config)
importFrom(babelwhale,test_docker_installation)
importFrom(babelwhale,test_singularity_installation)
importFrom(dynutils,extract_row_to_list)
importFrom(dynutils,test_h5_installation)
importFrom(glue,glue)
importFrom(igraph,"%--%")
importFrom(igraph,"%->%")
importFrom(igraph,E)
importFrom(igraph,V)
importFrom(igraph,are_adjacent)
importFrom(igraph,degree)
importFrom(igraph,distances)
importFrom(igraph,graph_from_data_frame)
importFrom(igraph,is_directed)
importFrom(igraph,layout_with_fr)
importFrom(igraph,neighborhood)
importFrom(methods,as)
importFrom(methods,formalArgs)
importFrom(methods,is)
importFrom(purrr,discard)
importFrom(purrr,list_modify)
importFrom(purrr,map2_int)
importFrom(readr,read_file)
importFrom(reshape2,acast)
importFrom(reshape2,melt)
importFrom(stats,dnorm)
importFrom(stringr,str_length)
importFrom(stringr,str_replace)
importFrom(tibble,as_tibble)
importFrom(tibble,column_to_rownames)
importFrom(tibble,deframe)
importFrom(tibble,enframe)
importFrom(tibble,is_tibble)
importFrom(tibble,lst)
importFrom(tibble,rownames_to_column)
importFrom(tibble,tibble)
importFrom(tibble,tribble)
importFrom(utils,adist)
importFrom(utils,capture.output)
importFrom(utils,data)
importFrom(utils,head)
importFrom(utils,installed.packages)
importFrom(utils,lsf.str)
importFrom(yaml,read_yaml)
